/*
 * ProFrom - Professzionális Felhasználói Felületek $Id: _lib.js,v 1.17 2005/10/10 14:31:55 gyuris Exp $
 */


/**
 * $ prototype_A.js,v 1.7 2005/06/10 12:47:13 gyuris Exp $
 * prototype A
 * @package  lib.prototypeA
 * @author   Gyuris Gellért
 */
/**
 * Function.prototype.getName - visszaadja egy funkció nevét, IE-ben nincs segéd.
 * @return String  A funkció neve.
 */
Function.prototype.getName = function () {
	var aTemp;
	if ( typeof this.name == 'string' ) {
		return this.name;
	}
	else {
		aTemp = /function\s([\w]+)\(/g.exec( this.toString() );
		return this.name = ( aTemp != null && typeof aTemp[1] != 'undefined' ) ? aTemp[1] : '';
	};
};
/**
 * String.prototype.trim - letörli a string végéről a fölösleges üres karatereket.
 * @return String  A String új értéke.
 */
String.prototype.trim = function() {
	return this.replace(/(^\s*)|(\s*$)/g, '');
};
/**
 * String.prototype.escapeHTML - egy Stringet bekódol forráskód-megjelenítésre
 * @return String  A String új, forráskód-megjeleníthető értéke.
 */
String.prototype.escapeHTML = function() {
	var s = this.toString();
	s = s.replace(/\&/g, '&amp;');
	s = s.replace(/\</g, '&lt;');
	s = s.replace(/\>/g, '&gt;');
	return s;
};
/**
 * String.prototype.unescapeHTML - egy Stringet bekódol megjelenítésre
 * @return String  A String új, HTML-ként értzelmezhető értéke.
 */
String.prototype.unescapeHTML = function() {
	var s = this.toString();
	s = s.replace(/\&lt;/g,  '<');
	s = s.replace(/\&gt;/g,  '>');
	s = s.replace(/\&amp;/g, '&');
	return s;
};
/**
 * String.prototype.toInt - parseInt úgy, hogy mindenképpen számot adjon vissza
 * @return Number  A leparsolt szám. Pl.: 'a112' -> 0, '23a1' -> 23,  '1.2a34bc' -> 1
 */
String.prototype.toInt = function( nBase ) {
	var nVal;
	if ( typeof( nBase ) == 'undefined' ) {
		nBase = 10;
	};
	nVal = parseInt( this.toString() , nBase );
	if ( isNaN( nVal ) ) {
		nVal = 0;
	};
	return nVal;
};
/**
 * String.prototype.toFloat - egy string számmá alakítása a tizedeshelyek elvetésével
 * @return Number  A leparsolt szám. Pl.: '01.2a34bc' -> 1234
 */
String.prototype.toFloat = function() {
	return parseFloat( ('0' + this.toString() ).replace(/[^0-9]/g,''), 10)
};
/**
 * String.prototype.toSequence - számok kinyerése egy szringből a tizedeshelyek elvetésével.
 * @return String  A leparsolt szöveg. Pl.: '01.2a34bc' -> '01234'
 */
String.prototype.toSequence = function() {
	return this.toString().replace(/[^0-9]/g,'');
};
/**
 * String.prototype.endsWith - egy String a megadott sztringre végződik-e? (Java)
 * @param sEnd String  A keresett sztring.
 * @return Boolean     true vagy false
 */
String.prototype.endsWith = function( sEnd ) {
	if ( typeof sEnd != 'string' ) {
		sEnd = sEnd.toString();
	};
	return ( this.toString().substring( this.toString().length - sEnd.length, this.toString().length ) == sEnd ) ? true : false;
};
/**
 * String.prototype.startsWith - egy String a megadott sztringgel kezdődik-e? (Java)
 * @param sStart String  A keresett sztring.
 * @param nStart Number  Opcionális. Megadható egy kezdőpont, ahonnan a vizsgálat kezdődik. Elhagyása a 0-t jelenti.
 * @return Boolean       true vagy false
 */
String.prototype.startsWith = function( sStart, nStart ) {
	if ( typeof sStart != 'string' ) {
		sStart = sStart.toString();
	};
	if ( !nStart ) {
		nStart = 0;
	};
	if ( typeof nStart != 'number' ) {
		nStart = nStart.toString().toInt();
	};
	return ( this.toString().substring( nStart, nStart + sStart.length ) == sStart ) ? true : false;
};
/**
 * String.prototype.toUpperCaseFirst - Egy string első betűjét nagybetűssé teszi (Java)
 * @return String  A nagybetűssé tett sztring.
 */
String.prototype.toUpperCaseFirst = function() {
	return this.toString().charAt(0).toUpperCase() + this.toString().substring( 1, this.toString().length );
};
/**
 * String.prototype.toUpperCaseWords - Egy string minden szavának első betűjét nagybetűssé teszi (Java)
 * @return String  A nagybetűssé tett sztring.
 * XXX - más karakterek
 */
String.prototype.toUpperCaseWords = function() {
	var i, aString = this.toString().split(' ');
	for ( i = 0; i < aString.length; i++ ) {
		aString[i] = aString[i].toUpperCaseFirst();
	};
	return aString.join(' ');
};



/**
 * $ browserCheck.js,v 1.12 2005/06/07 13:06:32 gyuris Exp $
 * @package  lib.browserCheck
 * @author   Gyuris Gellért
 */
var is = {
	/**
	 * @constructor
	 */
	getUserAgents : function() { 
		// segédfunkciók
		this.geckoGetRv = function() {
			var aTemp = /rv:(\d+\.)(\d+(\.\d+)?)/g.exec(this.agent);
			return aTemp[1] + aTemp[2].toSequence();
		};
		this.getVersion = function() {
			var sId;
			switch ( this.app ) {
				case 'gecko' :
					return this.geckoRv;
					break;
				case 'ie' :
					sId = 'msie ';
					break;
				case 'opera' :
					sId = ( this.agent.indexOf( 'opera/' ) > -1 ) ? 'opera/' : 'opera ';
					 break;
				case 'khtml' :
					sId = ( this.saf ) ? 'applewebkit/' : 'konqueror/';
					break;
				case 'ns4' :
					sId = 'mozilla/';
					break;
			};
			return parseFloat( '0' + this.agent.substr( this.agent.indexOf( sId ) + sId.length ), 10 );
		};
		// adatok átvétele
		this.ver         = navigator.appVersion.toLowerCase();
		this.agent       = navigator.userAgent.toLowerCase();
		this.platform    = navigator.platform.toLowerCase();
		this.product     = new String( navigator.product ).toLowerCase();
		this.productSub  = new String( navigator.productSub ).toLowerCase();
		this.vendor      = new String( navigator.vendor ).toLowerCase();
		this.vendorSub   = new String( navigator.vendorSub ).toLowerCase();
		this.opera       = typeof ( window.opera ) != 'undefined';
		this.dom         = document.getElementById ? true : false;
		this.compatMode  = new String( document.compatMode ).toLowerCase(); // 'css1compat', 'backcompat', 'quirksmode'
		
		// platformok
		this.win         = this.platform.indexOf("win") > -1;
		this.linux       = ( this.platform.indexOf("linux") > -1 || this.platform.indexOf("x11") > -1 );
		this.mac         = this.platform.indexOf("mac") > -1;
	
		// böngészők
		// khtml
		this.khtml       = ( this.agent.indexOf("khtml") > -1 || this.product.indexOf("khtml") > -1 );
		this.konq        = ( this.agent.indexOf("konqueror") > -1 || this.product.indexOf("konqueror") > -1 );
		this.saf         = ( this.agent.indexOf("safari") > -1 || this.ver.indexOf("safari") > -1 );
		// opera
		this.opera       = ( this.opera || this.agent.indexOf("opera") > -1 ); // nem win platformon az opera obj nem jön létre
		this.opera5      = ( this.opera && this.agent.indexOf("opera 5") > -1 );
		this.opera6      = ( this.opera && ( this.agent.indexOf("opera 6") > -1 || this.agent.indexOf("opera/6") > -1 ) );
		this.opera7      = ( this.opera && ( this.agent.indexOf("opera 7") > -1 || this.agent.indexOf("opera/7") > -1 ) );
		this.opera8      = ( this.opera && ( this.agent.indexOf("opera 8") > -1 || this.agent.indexOf("opera/8") > -1 ) );
		// IE
		this.ie          = ( this.ver.indexOf('msie') != -1 && !this.opera ) ? true : false;
		this.ie4         = ( document.all && !this.dom && !this.opera ) ? true : false;
		this.ie5         = ( document.all && this.ver.indexOf("msie 5.0") > -1 && !this.opera ) ? true : false; 
		this.ie5mac      = ( this.ie5 && this.mac ) ? true : false; 
		this.ie55        = ( document.all && this.ver.indexOf("msie 5.5") > -1 && !this.opera ) ? true : false; 
		this.ie6         = ( document.all && this.ver.indexOf("msie 6" )  > -1 && !this.opera ) ? true : false;
		this.ie7         = ( document.all && this.ver.indexOf("msie 7" )  > -1 && !this.opera ) ? true : false;
		this.ieJSBuild   = ( this.ie ) ? ScriptEngineBuildVersion() : '';
		this.ieJSVersion = ( this.ie ) ? ScriptEngineMajorVersion() + '.' + ScriptEngineMinorVersion() : '';
		// mozilla
		this.ns4         = ( document.layers && !this.dom ) ? true : false;
		this.gecko       = ( this.product == "gecko" && !this.khtml ) ? true : false;
		this.geckoRv     = ( this.gecko ) ? this.geckoGetRv() : 0;
		this.gecko1      = ( this.gecko && Number( this.productSub ) > 20020530 ) ? true : false;
		this.moz1        = ( this.gecko && this.vendor == '' && !( this.geckoRv < 1 ) ) ? true : false;
		this.ns6         = ( this.gecko && this.vendor == 'netscape6' && parseFloat( this.vendorSub ) >= 6 && parseFloat( this.vendorSub ) < 7 ) ? true : false;
		this.ns7         = ( this.gecko && this.vendor == 'netscape' && parseFloat( this.vendorSub ) >= 7 ) ? true : false;
		this.ff          = ( this.gecko && ( this.vendor == 'mozilla firebird' || this.vendor == 'phoenix' || this.vendor == 'firefox' ) );
		this.cm          = ( this.gecko && ( this.vendor == 'chimera' || this.vendor == 'camino' ) );
		this.beo         = ( this.gecko && this.vendor == 'beonex' );
		this.kmel        = ( this.agent.indexOf('k-meleon') > -1 ) ? true : false;
		// alkalmazás-verziószám
		this.app         = ( ( this.ie ) ?  'ie' : ( this.gecko ) ? 'gecko' : ( this.opera ) ?  'opera' : ( this.khtml ) ? 'khtml' : ( this.ns4 ) ? 'ns4' : 'undefined' );
		this.appVer      = this.getVersion();
	
		// csoportok
		this.bs4         = ( this.ie || this.ns4 || this.gecko || this.opera || this.khtml );
		this.bs5         = ( ( this.ie && this.appVer >= 5.5 ) || this.gecko || ( this.opera && this.appVer >= 7  ) || this.saf );
		this.bss         = ( this.gecko || ( this.opera && this.appVer >= 7  ) || this.khtml );
		this.min         = ( this.bs5 || this.ie5 || this.opera || this.khtml );
		return this;
	}
};
is.getUserAgents();


/**
 * $ eventBinding.js,v 1.9 2005/10/10 14:06:58 gyuris Exp $
 * @package  lib.eventBinding
 * @author   Gyuris Gellért
 * @see      browserCheck, prototype A
 */
/**
 * addEvent - egy esemény csatolása. Alapfüggvény.
 * @param obj DOMElement     Az elem, amihez csatolunk.
 * @param type String        Az esmeméyn típusa: pl.: 'click', 'mouseover' ('on' nélkül).
 * @param fn Function  A függvény, melyet csatolunk.
 */
function addEvent( obj, type, fn ) {
	if ( obj.addEventListener ) {
		obj.addEventListener( type, fn, false );
	}
	else if	( obj.attachEvent ) {
		obj['e'+type+fn] = fn;
		obj[type+fn] = function(){ obj['e'+type+fn]( window.event ); };
		obj.attachEvent( 'on'+type, obj[type+fn] );
	};
};
/**
 * removeEvent - egy esemény csatolása. Alapfüggvény.
 * @param obj DOMElement     Az elem, amitől elveszünk.
 * @param type String        Az esmeméyn típusa: pl.: 'click', 'mouseover' ('on' nélkül).
 * @param fn Function  A függvény, melyet elveszünk.
 */
function removeEvent( obj, type, fn ) {
	if ( obj.removeEventListener ) {
		obj.removeEventListener( type, fn, false );
	}
	else if ( obj.detachEvent ) {
		obj.detachEvent( 'on'+type, obj[type+fn] );
		obj[type+fn] = null;
	};
};


/**
 * $ className.js,v 1.4 2004/08/19 11:59:21 gyuris Exp $
 * @package  lib.className
 * @author   Gyuris Gellért
 */
/**
 * removeClass - eltávolítja egy elem CSS oszályai közül a megadottat
 * @param el DOMElement      A elem, amelyen módosítunk.
 * @param sClassName String  A CSS osztály neve.
 * @return String            A keletkezett osztálynév.
 */
function removeClass( el, sClassName ) {
	var i, aClass, aNewClass = [];
	if ( hasClass( el, sClassName ) ) {
		aClass = el.className.split(' ');
		for ( i = aClass.length; i > 0; ) {
			if ( aClass[--i] != sClassName ) {
				aNewClass.unshift( aClass[i] );
			};
		};
		el.className = aNewClass.join(' ');
	};
	return el.className;
};
/**
 * addClass - hozzáadja egy elem CSS oszályai közé legutolsó helyre a megadottat,
 * ha már szerepel, akkor kiemeli a legutolsó helyre.
 *
 * @param el DOMElement      A elem, amelyen módosítunk.
 * @param sClassName String  A CSS osztály neve.
 * @return String            A keletkezett osztálynév.
 */
function addClass( el, sClassName ) {
	if ( el.className == '' ) {
		el.className = sClassName;
	}
	else if ( !hasClass( el, sClassName ) ) { // nincs szerepe a sorrendiségnek
		el.className += ' ' + sClassName;
	};
	return el.className;
};
/**
 * hasClass - megnézi, hogy egy elem CSS oszályai között szerepel-e a megadott?
 * @param el DOMElement      A elem, amelyen a vizsgálatot végezzük.
 * @param sClassName String  A CSS osztály neve.
 * @return Boolean           Szerepel-e vagy sem benne?
 */
function hasClass( el, sClassName ) {
	var i, aClass;
	aClass = el.className.split(' ');
	for ( i = aClass.length; i > 0; ) {
		if ( aClass[--i] == sClassName ) {
			return true;
		};
	};
	return false;
};


/**
 * $ child.js,v 1.4 2004/08/19 11:59:21 gyuris Exp $
 * @package  lib.child
 * @author   Gyuris Gellért
 * @see      prototypeA
 */
/**
 * getChildIndex - visszaadja a gyermek sorszámát
 * @param elChild DOMNode  A csomópont, amelynek a sorszámára vagyunk kíváncsiak.
 * @return Number          Hanyadik csomópont.
 * @return null            Nincs szülője.
 */
function getChildIndex( elChild ) {
	var i;
	if ( elChild.parentNode == null ) {
		return null;
	};
	for ( i = 0; i < elChild.parentNode.childNodes.length; i++ ) {
		if ( elChild.parentNode.childNodes.item(i) == elChild ) {
			return i;
			break;
		};
	};
	return null;
}
/**
 * getContextNodes - visszaadja a kért csomópont-típusú leszármazottjait. A 
 * getAllChildElement v2.0, getAllChildNode v2.0 ennek két önálló régebbi 
 * speciális megvalósítása, melyet kompatibilitás miatt megőriztem.
 *
 * @param elRoot DOMNode  A csomópont, amelynek a leszármazottait kérjük 
 * @param aType Array     A leszármazott csomópont-típusok, Lásd a Node
 * @return Array          A megadott csomópont-típusoknak megfelelő leszármazottak.
 */
function getContextNodes( elRoot, aType ) {
	var aNodes = [];
	function searchNodes( el ) {
		var i, j;
		if ( !el.hasChildNodes() ) {
			return;
		};
		for ( i = 0; i < el.childNodes.length; i++ ) {
			for ( j = 0; j < aType.length; j++ ) {
				if ( el.childNodes.item(i).nodeType == aType[j] ) {
					aNodes[aNodes.length] = el.childNodes.item(i);
					break;
				};
			};
			if ( el.childNodes[i].nodeType == Node.ELEMENT_NODE ) {
				searchNodes( el.childNodes.item(i) );
			};
		};
	};
	searchNodes( elRoot );
	return aNodes;
}
/**
 * getAllChildElement - Lásd: getContextNodes;
 * @param elRoot DOMNode  A csomópont, amelynek a leszármazottait kérjük 
 */
function getAllChildElement( elRoot ) {
	elRoot.allEl = getContextNodes( elRoot, [ Node.ELEMENT_NODE ] );
};
/**
 * getAllChildNode - Lásd: getContextNodes;
 * @param elRoot DOMNode  A csomópont, amelynek a leszármazottait kérjük 
 */
function getAllChildNode( elRoot ) {
	elRoot.allNodes = getContextNodes( elRoot, [ Node.ELEMENT_NODE, Node.TEXT_NODE, Node.CDATA_SECTION_NODE, Node.COMMENT_NODE ] );
};
/**
 * getFirstElement - visszaadja egy csomópont első ELEMENT_NODE-ját
 * @param el DOMElement  A csomópont, amelynek első elemét kérjük.
 * @return DOMELement    Az első elem.
 * @return null          Ha nincs első elem.
 */
function getFirstElement( el ) {
	var i;
	if ( !el.hasChildNodes() ) {
		return null; // ha nem ELEMENT_NODE a szülő
	};
	for ( i = 0 ; i < el.childNodes.length; i++ ) {
		if ( el.childNodes.item(i).nodeType == Node.ELEMENT_NODE ) {
			return el.childNodes.item(i);
			break;
		};
	};
	return null;
};
/**
 * getLastElement - visszadja egy csomópont utolsó ELEMENT_NODE-ját
 *
 * @param el DOMElement  A csomópont, amelynek utolsó elemét kérjük.
 * @return DOMELement    Az utoló elem.
 * @return null          Ha nincs utolsó elem.
 */
function getLastElement( el ) {
	var i;
	if ( !el.hasChildNodes() ) {
		return null; // ha nem ELEMENT_NODE a szülő
	};
	for ( i = el.childNodes.length - 1 ; i >= 0; i-- ) {
		if ( el.childNodes.item(i).nodeType == Node.ELEMENT_NODE ) {
			return el.childNodes.item(i);
			break;
		};
	};
	return null;
};
/**
 * getNextElement - visszaadja egy egy elem testvérei közül a következő elemet
 *
 * @param elChild DOMElement  A gyermek-csomópont, amely szülőjének következő elemét kérjük.
 * @return DOMELement         A következő elem.
 * @return null               Ha nincs következő elem.
 */
function getNextElement( elChild ) {
	function getNext( el ) {
		if ( el.nextSibling == null ) {
			return null;
		};
		if ( el.nextSibling.nodeType == Node.ELEMENT_NODE ) {
			return el.nextSibling;
		};
		return getNext( el.nextSibling );
	};
	return getNext( elChild );
};
/**
 * getPreviousElement - visszaadja egy egy elem testvérei közül az előző elemet
 *
 * @param elChild DOMElement  A gyermek-csomópont, amely szülőjének előző elemét kérjük.
 * @return DOMELement         Az előző elem.
 * @return null               Ha nincs előző elem.
 */
function getPreviousElement( elChild ) {
	function getPrevious( el ) {
		if ( el.previousSibling == null ) {
			return null;
		};
		if ( el.previousSibling.nodeType == Node.ELEMENT_NODE ) {
			return el.previousSibling;
		};
		return getPrevious( el.previousSibling );
	};
	return getPrevious( elChild );
};
/**
 * removeEmptyTextNode - eltávolítja egy elem üres TEXT_NODE-jait
 *
 * @param elRoot DOMElement  A csomópont, amely üres TEXT_NODE-jait kitöröljük
 * @return Array             A csomópontok, melyek ki lettek törölve.
 */
function removeEmptyTextNode( elRoot ) {
	var re, aNodes, aRemovedNodes = [];
	re = /^[\s\n\t]*$/;
	aNodes = getContextNodes( elRoot, [ Node.TEXT_NODE ] );
	for ( i = 0; i < aNodes.length; i++ ) {
		if ( aNodes[i].nodeType != Node.TEXT_NODE ) {
			continue;
		};
		if ( re.test( aNodes[i].nodeValue ) ) {
			aRemovedNodes[aRemovedNodes.length] = aNodes[i].parentNode.removeChild( aNodes[i] );
		};
	};
	return aRemovedNodes;
};
/**
 * getTextContent - bármilyen csomópont szöveges tartalmát visszaadja (ha lehetséges neki)
 * @param nodeRoot DOMNode  A csomópont, amelynek szöveges tartalmára vagyunk kiváncsiak
 * @return String           A tartalom
 */
function getTextContent( nodeRoot ) {
	switch ( nodeRoot.nodeType ) {
		case  2 : // Node.ATTRIBUTE_NODE
		case  5 : // Node.ENTITY_REFERENCE_NODE
		case  6 : // Node.ENTITY_NODE
		case  7 : // Node.PROCESSING_INSTRUCTION_NODE
		case  9 : // Node.DOCUMENT_NODE
		case 10 : // Node.DOCUMENT_TYPE_NODE
		case 11 : // Node.DOCUMENT_FRAGMENT_NODE
		case 12 : // Node.NOTATION_NODE
			return '';
			break;
		case  1 : // Node.ELEMENT_NODE
		case  3 : // Node.TEXT_NODE
		case  4 : // Node.CDATA_SECTION_NODE
		case  8 : // Node.COMMENT_NODE
			if ( is.gecko ) {
				return nodeRoot.textContent;
			}
			else {
				return ( nodeRoot.innerText ) ? nodeRoot.innerText : nodeRoot.nodeValue;
			};
	};
};


/**
 * $ attribute.js,v 1.6 2005/03/01 14:44:03 gyuris Exp $
 * @package  lib.attribute
 * @author   Gyuris Gellért
 * @see      browserCheck
 */
/**
 * isSpecified - Egy elem attribútuma deklarálva van-e?
 * Szabványos attr. esetén attributes['valami'].specified; nem szabvanyos 
 * attributum esetén: attributes.getNamedItem('valami') visszatérési értéke 
 * null, de csak 6-os Explorer; hasAttribute minden máshol
 *
 * @param nodeEl DOMElement  Az elem DOM objektumként.
 * @param sAttribute String  Az attribútum neve stringként.
 * @return Boolean           Dekralárva van, vagy sem?
 * @since                    1.4
 */
function isSpecified( nodeEl, sAttribute ) {
	if ( is.ie || ( is.opera && this.appVer >= 7 ) ) {
		/*getItemIndex( nodeEl, sAttribute ) != null ) { // normál 'core' attribútum
			return nodeEl.attributes[sAttribute].specified
		}*/
		if ( typeof nodeEl.attributes[sAttribute] != 'undefined' ) {
			return nodeEl.attributes[sAttribute].specified;
		};
		if ( is.ie5 || is.ie55 ) {
			return ( nodeEl.getAttribute( sAttribute ) ) ? true : false;
		}
		else if ( is.ie6 || is.ie7 || ( ( is.opera && this.appVer >= 7 ) ) ) {
			return ( nodeEl.attributes.getNamedItem( sAttribute ) ) ? true : false;
		};
	}
	else if ( is.bss ) { // opera7.5
		return nodeEl.hasAttribute( sAttribute );
	};
};
/**
 * getAttributeIndex - IE: visszaadja az attribútum sorszámát az attributes tömben
 * @param nodeEl DOMElement  Az elem DOM objektumként.
 * @param sAttribute String  Az attribútum neve stringként.
 * @return Number            Hanyadik attribútum.
 * @since                    1.0
 */
function getAttributeIndex( nodeEl, sAttribute ) {
	var i;
	sAttribute = sAttribute.toLowerCase();
	for ( i = 0; i < nodeEl.attributes.length; i++ ) {
		if ( nodeEl.attributes.item(i).nodeName.toLowerCase() == sAttribute ) {
			return i;
		};
	};
	return null;
};
/**
 * createId - vagy visszaadja az elem már meglévő Id-jét, vagy készít egy véletlen Id-t
 * @param el DOMELement  Az elem, amelynek id-t akarunk készíteni.
 * @return String        A string, mely idnek felel meg. IE esetén a beépített uniqueID használtatik.
 * @since                0.1
 */
function createId( el ) {
	if ( isSpecified( el, 'id' ) ) {
		return el.id;
	};
	if ( is.ie ) {
		return el.uniqueID;
	}
	else {
		function getRandom() {
			var strNum = Math.random().toString().toFloat();
			if ( strNum == 0 || strNum == 1 ) { 
				return getRandom();
			};
			return strNum;
		};
		return 'rID-' + getRandom();
	};
};


/**
 * $ getComputedStylePropertyValue.js,v 1.8 2005/06/07 13:06:32 gyuris Exp $
 * getComputedStylePropertyValue - visszadja az elem tényleges stílusának elemeit. FONTOS! Nem minden böngésző támogatja.
 * Gond nélkül megy Geckókban és IE-ben. Opera csak a 7.20-tól támogatja, az alatti csak visszadja a normális style 
 * értékeket. Nem megy KHTML (Safari 1.0) alatt, de már hírét hallottam, hogy készítik.
 * @package                       lib.getComputedStylePropertyValue
 * @author                        Gyuris Gellért
 * @see                           
 * @param elNode DOMElement       Az elem, melynek stílus-értékére vagyunk kíváncsiak.
 * @param sStyleProperty String   Az stílus deklaráció neve: pl. 'border-left-color'
 * @param sPseudoProperty String  A pszeudo deklráció neve: pl. 'fist-letter' - Ez csak Geckókban működik!, elhagyható
 * @return String                 A deklarácó értéke.
 */
function getComputedStylePropertyValue( elNode, sStyleProperty, sPseudoProperty ) {
	var aResult, i;
	if ( window.getComputedStyle ) {
		return window.getComputedStyle( elNode, sPseudoProperty ).getPropertyValue( sStyleProperty );
	}
	else if ( elNode.currentStyle ) {
		aResult = sStyleProperty.split('-');
		for ( i = 1; i < aResult.length; i++ ) {
			aResult[i] = aResult[i].toUpperCaseFirst();
		};
		sStyleProperty = aResult.join('');
		return elNode.currentStyle.getAttribute( sStyleProperty );
	};
	return elNode.style.getPropertyValue( sStyleProperty ); // khtml
};


/**
 * $ makeUnselectable.js,v 1.2 2004/08/19 11:59:21 gyuris Exp $
 * makeUnselectable - egy elemenek tiltja a kijelölését és fókuszba kerülését. Opera7 megoldatlan.
 * @package                    lib.makeUnselectable
 * @author                     Gyuris Gellért
 * @see                        browserCheck, prototype A
 * @param el DOMElement        Az elem, amelyen a műveletet végezzük.
 * @return el DOMElement       Az elem, a megváltozott paraméterekkel.
 */
function makeUnselectable( el ) {
	if ( el.nodeType != Node.ELEMENT_NODE ) {
		return false;
	};
	if ( is.ie ) {
		el.setAttribute('unselectable', 'on' );
		el.setAttribute('hidefocus', true );
	}
	else if ( is.gecko ) {
		el.style.MozUserSelect = 'none';
		el.style.MozUserFocus = 'none';
	};
	return el;
};


/**
 * $ displayChanger.js,v 1.6 2005/07/15 11:23:27 gyuris Exp $
 * displayChanger - megfordítja egy elem display-ét, vagy a megadottra állítja. 
 * @package               lib.displayChanger
 * @author                Gyuris Gellért
 * @see                   browserCheck, getComputedStylePropertyValue, prototypeA
 * @param el DOMElement   Az elem, melyneknek megjelenítését változtatjuk.
 * @param bValue Boolean  Opcionális; true: mutatva lesz, false: elrejtve lesz, 
 *                        elhagyásakor megfordul.
 * @return String         A beállított display
 */
function displayChanger( el, bValue ) {
	var oDisplay, sNodeName, sStyle;
	if ( el.nodeType != Node.ELEMENT_NODE ) {
		return null;
	};
	oDisplay = {
		'iframe' : [ 'inline', 'inline' ],
		'body' : [ 'block', 'block' ],
		'p' : [ 'block', 'block' ],
		'div' : [ 'block', 'block' ],
		'span' : [ 'inline', 'inline' ],
		'table' : [ 'table', 'block' ],
		'tbody' : [ 'table-row-group', 'block' ],
		'tfoot' : [ 'table-footer-group', 'block' ],
		'thead' : [ 'table-header-group', 'block' ],
		'tr' : [ 'table-row', 'block' ],
		'td' : [ 'table-cell', 'block' ],
		'th' : [ 'table-cell', 'block' ],
		'ul' : [ 'block', 'block' ],
		'ol' : [ 'block', 'block' ],
		'li' : [ 'list-item', 'list-item' ],
		'dl' : [ 'block', 'block' ],
		'dt' : [ 'block', 'block' ],
		'dd' : [ 'block', 'block' ],				
		'input' : [ 'inline', 'inline' ],
		'button' : [ 'inline', 'inline' ],
		'textarea' : [ 'inline', 'inline' ],
		'a' : [ 'inline', 'inline' ]
	};
	sNodeName = el.nodeName.toLowerCase();
	if ( typeof oDisplay[sNodeName] == 'undefined' ) {
		return null;
	};
	if ( typeof( bValue ) != 'undefined' ) { // ha megvan adva, hogy mire kell cserélni
		el.style.display = ( bValue == false ) ? 'none' : is.ie ? oDisplay[sNodeName][1] : oDisplay[sNodeName][0];
	}
	else { // ha meg kell fordítani
		sStyle = el.style.display == '' ? getComputedStylePropertyValue( el, 'display', '' ) : el.style.display;
		el.style.display = !( sStyle == 'none' || sStyle == '' ) ? 'none' : is.ie ? oDisplay[sNodeName][1] : oDisplay[sNodeName][0];
	};
	return el.style.display;
};

/**
 * $ createFullOffset.js,v 1.5 2005/02/21 08:27:43 gyuris Exp $
 * createFullOffset - visszadja az elem abszolút elhelyezekedését a látképen, 
 * vagy az elRoot-hoz viszonyítva.
 * @package              lib.createFullOffset
 * @author               Gyuris Gellért
 * @see                  browserCheck
 * @param el DOMElement  Az elem, melynek pozícióira kiváncsiak vagyunk.
 * @param elRoot DOMElement  Az elem, melynek pozícióira kiváncsiak vagyunk.
 * @return Object        offsetX, offsetY: x és y pozíciók számokkal
 */
function createFullOffset( el, elRoot ) {
	if ( el.nodeType != Node.ELEMENT_NODE ) {
		return { offsetX : null, offsetY : null };
	};
	if ( typeof elRoot != 'undefined' || !( document.getBoxObjectFor || el.getBoundingClientRect ) ) {
		function getFullOffset( el ) {
			var aOffset = [], aTempOffset = [];
			aOffset[0] = el.offsetLeft;
			aOffset[1] = el.offsetTop;
			if ( el.offsetParent != null && el.offsetParent != elRoot ) {
				aTempOffset = getFullOffset( el.offsetParent );
				aOffset[0] += aTempOffset[0];
				aOffset[1] += aTempOffset[1];
			};
			return aOffset;
		};
		if ( typeof elRoot == 'undefined' ) {
			elRoot = el.ownerDocument.documentElement || el.ownerDocument.body;
		};
		var aFullOffset = getFullOffset( el );
		el.offsetX = aFullOffset[0];
		el.offsetY = aFullOffset[1];
		return { offsetX : el.offsetX, offsetY : el.offsetY };
	};
	if ( document.getBoxObjectFor ) {
		var oBoxObject = el.ownerDocument.getBoxObjectFor( el ); // el bordertől meghüjül
		return { offsetX : oBoxObject.x, offsetY : oBoxObject.y };
	};
	if ( el.getBoundingClientRect ) {
		var oTextRectangle = el.getBoundingClientRect(); // body bordertől meghüjül
		return { offsetX : oTextRectangle.left, offsetY : oTextRectangle.top };
	};
};